@@ -12,6 +12,7 @@ class ExpaiExplanation:
                  access_token: str,
                  headers: dict,
                  server_name: str,
+                 raw_values,
                  session,
                  project,
                  visualizations,
@@ -33,6 +34,7 @@ class ExpaiExplanation:
         self.json_details = json_details
         self.explanation_type_id = explanation_type_id
         self.visualizations = visualizations
+        self.raw_values = raw_values
 
     def get_keys(self):
         """
@@ -77,6 +79,8 @@ class ExpaiExplanation:
 
         display(HTML(html))
 
+    def get_raw_values(self):
+        return self.raw_values
 
     def store_explanation(self,
                           explanation_name: str = None,
@@ -88,6 +92,7 @@ class ExpaiExplanation:
         :param explanation_summary: Description for the plot.
         """
         assert explanation_name is not None, "You must specify a name for the explanation."
+
         if keys:
             assert set(keys).issubset(self.visualizations.keys()), "Some of the keys you introduce are not available. Please, try again."
         else:
@@ -97,7 +102,7 @@ class ExpaiExplanation:
         data['explanation_type_id'] = self.explanation_type_id
         data['explanation_name_des'] = explanation_name
         data['explanation_summary_des'] = explanation_summary
-        data['explanation_json'] = {k: v for k, v in self.visualizations.items() if k in keys}
+        data['explanation_json'] = list(self.visualizations.values())[0] #{k: v for k, v in self.visualizations.items() if k in keys}
         data['model_id'] = self.model_id
         data['sample_id'] = self.sample_id
 
