@@ -3,6 +3,7 @@ import logging
 from expai.expai_explainer import ExpaiModelExplainer
 from expai.expai_fairness import ExpaiModelFairness
 from expai.utils import generate_response
+from expai.expai_explanation import ExpaiExplanation
 import io
 import pandas as pd
 import ast
@@ -59,7 +60,7 @@ class ExpaiProject:
             return generate_response(response, ['models'])
 
 
-    def create_model(self, model_path: str = None, is_supervised: bool = True, model_name: str = None,
+    def create_model(self, model_path: str = None, model_name: str = None,
                      model_summary: str = None, model_library: str = None, model_objective: str = None,
                      model_prediction_type: str = None, output_classes: list = None, model_cutoff: float = None):
         """
@@ -80,7 +81,7 @@ class ExpaiProject:
 
         data = {"model_name_des": model_name,
                 "model_summary_des": model_summary,
-                "is_supervised_flag": 1 if is_supervised else 0,
+                "is_supervised_flag": 1,
                 "model_cutoff_num": model_cutoff,
                 'model_library_des': model_library,
                 'model_objective_des': model_objective,
@@ -391,8 +392,11 @@ class ExpaiProject:
 
         if response.ok:
             if 'data' in response.json():
-                df = pd.read_json(response.json().get('data'), orient='records')
-                return df
+                df = pd.DataFrame(response.json().get('data'))
+                df = df.rename(columns={'__expai_index__': 'index'})
+                df['index'] = df['index'].astype(int)
+                df = df.set_index('index')
+                return df.sort_index()
             else:
                 raise Exception("There was en error generating the DataFrame. No data was returned from API. Please, try again.")
         else:
@@ -411,3 +415,44 @@ class ExpaiProject:
                 return sample['sample_id']
         return None
 
+    #########################
+    ###    EXPLANATIONS   ###
+    #########################
+
+    def explanation_list(self, search_by: str = None, exact_search: str = None):
+        """
+        List all samples associated with this project
+        :return: list of samples
+        """
+
+        if exact_search is not None:
+            response = self.sess.request("GET",
+                                         self.server_name + "/api/projects/{}/explanation/list/contains/{}".format(self.project_id, exact_search),
+                                         headers=self.headers)
+
+            if 'explanations' in response.json().keys():
+                for exp in response.json()['explanations']:
+                    if exp['explanation_name_des'] == exact_search:
+                        return ExpaiExplanation(model_id=exp['model_id'],
+                                                project_id=exp['project_id'],
+                                                sample_id=exp['sample_id'],
+                                                access_token=self.access_token,
+                                                server_name=self.server_name,
+                                                headers=self.headers,
+                                                session=self.sess,
+                                                project=self)
+            logging.error("We could not find an explanation with this exact name. Try again or consider using search_by parameter to find similar explanations")
+            return None
+
+        elif search_by is not None:
+            response = self.sess.request("GET",
+                                         self.server_name + "/api/projects/{}/explanation/list/contains/{}".format(
+                                             self.project_id, search_by),
+                                         headers=self.headers)
+            return generate_response(response, ['explanations'])
+
+        else:
+            response = self.sess.request("GET", self.server_name + "/api/projects/{}/explanation/list".format(self.project_id),
+                                         headers=self.headers)
+
+            return generate_response(response, ['explanations'])
\ No newline at end of file
