@@ -4,7 +4,7 @@ from expai.expai_project import ExpaiProject
 from expai.utils import generate_response
 
 
-class ExpaiLogin:
+class ExpaiAccount:
     def __init__(self, email: str = None, user_pass: str = None, access_token: str = None, server_name: str = "https://api.expai.io:443"):
         assert email is not None and user_pass is not None or access_token is not None, "Please, introduce your email and password or access_token"
 
@@ -40,6 +40,8 @@ class ExpaiLogin:
 
             self.sess = requests.session()
             response = self.sess.get(self.server_name + "/api/auth/check", headers=self.headers)
+            if not response.ok:
+                raise Exception("Please, introduce a valid token.")
 
     def project_list(self, search_by: str = None, exact_search: str = None):
         """
