@@ -1,8 +1,8 @@
-from expai.expai_requests import ExpaiLogin
+from expai.expai_requests import ExpaiAccount
 import os
 
 if __name__ == '__main__':
-    expaireq = ExpaiLogin(email="test@test.com", user_pass="test", access_token="6H19l-zXUzJVli2bcEMENssBjx0Ph4dnI0rmNtWcVac")
+    expaireq = ExpaiAccount(email="test@test.com", user_pass="test", access_token="6H19l-zXUzJVli2bcEMENssBjx0Ph4dnI0rmNtWcVac")
     models = expaireq.get_allowed_models()
     projects = expaireq.project_list(search_by='Proy')
     project = expaireq.get_project(project_name='Proyecto Test DAG')
